import React, {useEffect, useState} from "react";
import {connect, useDispatch} from "react-redux";
import {actions as categoryActions} from "../../@redux/categoryRedux";
import {Link} from "react-router-dom";
import {FontAwesomeIcon} from "@fortawesome/react-fontawesome";
import { useLocation } from 'react-router';

const MenuCategories = (props: any) => {
    const dispatch = useDispatch();
    const location = useLocation();

    const [update, setUpdate] = useState(false)
    useEffect(() => {
        setTimeout(() => {
            updateMenuPointer('')
        }, 500)
    },[location.pathname, update]);

    const updateMenuPointer = value => {
        let menu = document.getElementsByClassName('new-menu') as HTMLCollectionOf<HTMLElement>;
        if (menu.length != 0) {
            menu[0].style.pointerEvents = value;
        }
        if(value === 'none') {
            setUpdate(!update)
        }
    }


    useEffect(() => {
        if (props.category.categoryTree.length == 0) {
            dispatch(categoryActions.getCategoryTree());
        }
    }, []);

    return (
        <div className="third-new-header nav-link">
            All Categories
            <div className="new-menu">
                <ul className="position-relative">
                    {props.category.categoryTree?.map(category => (
                        <li>
                            <div className="d-flex justify-content-between align-items-center">
                                <Link
                                    to={"/category/subcategory/" + category.slug}
                                    onClick={() => updateMenuPointer('none')}
                                >   <div className="menu-title">
                                    <FontAwesomeIcon
                                        icon={category.icon ? category.icon : "beer"}
                                        color="white"
                                    />
                                    <span> {category.name} </span>
                                </div>
                                </Link>
                                <FontAwesomeIcon
                                    icon={"chevron-right"}
                                    color="#787c87"
                                />
                            </div>
                            <div className="sub-menu">
                                <div className="wrapper">
                                    <div className="d-flex flex-wrap p-3">
                                        {category.child.map((subCategory, index) => (
                                            <div className="menu-item">
                                                <Link
                                                    to={"/productsByCategory/" + subCategory.slug}
                                                    onClick={() => updateMenuPointer('none')}
                                                    className="item"
                                                    key={index}
                                                >
                                                    {subCategory.name}
                                                </Link>
                                            </div>
                                        ))}
                                    </div>
                                </div>
                            </div>
                        </li>
                    ))}
                    <li>
                        <Link to={"/view-all-category"}>
                            <div className="d-flex justify-content-between align-items-center">
                                <div className="menu-title align-items-center">
                                    <div className="mr-2">
                                        <img src="/images/giftyellow.png" alt="shopstick"/>
                                    </div>
                                    <span className="pt-1"> All Categories </span>
                                </div>
                            </div>
                        </Link>
                    </li>
                </ul>
            </div>
        </div>
    )
}
const mapStateToProps = ({category}) => ({
    category,
});
export default connect(mapStateToProps)(MenuCategories);